@@ -1,13 +1,11 @@
+from __future__ import annotations
+
 import signal
-import socket
 import threading
-
-try:
-    from time import monotonic
-except ImportError:
-    from time import time as monotonic
-
 import time
+import typing
+from socket import socket, socketpair
+from types import FrameType
 
 import pytest
 
@@ -20,24 +18,25 @@ from urllib3.util.wait import (
     wait_for_write,
 )
 
-from .socketpair_helper import socketpair
+TYPE_SOCKET_PAIR = typing.Tuple[socket, socket]
+TYPE_WAIT_FOR = typing.Callable[..., bool]
 
 
 @pytest.fixture
-def spair():
+def spair() -> typing.Generator[TYPE_SOCKET_PAIR, None, None]:
     a, b = socketpair()
     yield a, b
     a.close()
     b.close()
 
 
-variants = [wait_for_socket, select_wait_for_socket]
+variants: list[TYPE_WAIT_FOR] = [wait_for_socket, select_wait_for_socket]
 if _have_working_poll():
     variants.append(poll_wait_for_socket)
 
 
 @pytest.mark.parametrize("wfs", variants)
-def test_wait_for_socket(wfs, spair):
+def test_wait_for_socket(wfs: TYPE_WAIT_FOR, spair: TYPE_SOCKET_PAIR) -> None:
     a, b = spair
 
     with pytest.raises(RuntimeError):
@@ -56,7 +55,7 @@ def test_wait_for_socket(wfs, spair):
     try:
         while True:
             a.send(b"x" * 999999)
-    except (OSError, socket.error):
+    except OSError:
         pass
 
     # Now it's not writable anymore
@@ -80,7 +79,7 @@ def test_wait_for_socket(wfs, spair):
         wfs(b, read=True)
 
 
-def test_wait_for_read_write(spair):
+def test_wait_for_read_write(spair: TYPE_SOCKET_PAIR) -> None:
     a, b = spair
 
     assert not wait_for_read(a, 0)
@@ -96,7 +95,7 @@ def test_wait_for_read_write(spair):
     try:
         while True:
             a.send(b"x" * 999999)
-    except (OSError, socket.error):
+    except OSError:
         pass
 
     # Now it's not writable anymore
@@ -105,18 +104,18 @@ def test_wait_for_read_write(spair):
 
 @pytest.mark.skipif(not hasattr(signal, "setitimer"), reason="need setitimer() support")
 @pytest.mark.parametrize("wfs", variants)
-def test_eintr(wfs, spair):
+def test_eintr(wfs: TYPE_WAIT_FOR, spair: TYPE_SOCKET_PAIR) -> None:
     a, b = spair
     interrupt_count = [0]
 
-    def handler(sig, frame):
+    def handler(sig: int, frame: FrameType | None) -> typing.Any:
         assert sig == signal.SIGALRM
         interrupt_count[0] += 1
 
     old_handler = signal.signal(signal.SIGALRM, handler)
     try:
         assert not wfs(a, read=True, timeout=0)
-        start = monotonic()
+        start = time.monotonic()
         try:
             # Start delivering SIGALRM 10 times per second
             signal.setitimer(signal.ITIMER_REAL, 0.1, 0.1)
@@ -125,7 +124,7 @@ def test_eintr(wfs, spair):
         finally:
             # Stop delivering SIGALRM
             signal.setitimer(signal.ITIMER_REAL, 0)
-        end = monotonic()
+        end = time.monotonic()
         dur = end - start
         assert 0.9 < dur < 3
     finally:
@@ -136,11 +135,11 @@ def test_eintr(wfs, spair):
 
 @pytest.mark.skipif(not hasattr(signal, "setitimer"), reason="need setitimer() support")
 @pytest.mark.parametrize("wfs", variants)
-def test_eintr_zero_timeout(wfs, spair):
+def test_eintr_zero_timeout(wfs: TYPE_WAIT_FOR, spair: TYPE_SOCKET_PAIR) -> None:
     a, b = spair
     interrupt_count = [0]
 
-    def handler(sig, frame):
+    def handler(sig: int, frame: FrameType | None) -> typing.Any:
         assert sig == signal.SIGALRM
         interrupt_count[0] += 1
 
@@ -154,10 +153,10 @@ def test_eintr_zero_timeout(wfs, spair):
             signal.setitimer(signal.ITIMER_REAL, 0.001, 0.001)
             # Hammer the system call for a while to trigger the
             # race.
-            end = monotonic() + 5
+            end = time.monotonic() + 5
             for i in range(100000):
                 wfs(a, read=True, timeout=0)
-                if monotonic() >= end:
+                if time.monotonic() >= end:
                     break
         finally:
             # Stop delivering SIGALRM
@@ -170,22 +169,22 @@ def test_eintr_zero_timeout(wfs, spair):
 
 @pytest.mark.skipif(not hasattr(signal, "setitimer"), reason="need setitimer() support")
 @pytest.mark.parametrize("wfs", variants)
-def test_eintr_infinite_timeout(wfs, spair):
+def test_eintr_infinite_timeout(wfs: TYPE_WAIT_FOR, spair: TYPE_SOCKET_PAIR) -> None:
     a, b = spair
     interrupt_count = [0]
 
-    def handler(sig, frame):
+    def handler(sig: int, frame: FrameType | None) -> typing.Any:
         assert sig == signal.SIGALRM
         interrupt_count[0] += 1
 
-    def make_a_readable_after_one_second():
+    def make_a_readable_after_one_second() -> None:
         time.sleep(1)
         b.send(b"x")
 
     old_handler = signal.signal(signal.SIGALRM, handler)
     try:
         assert not wfs(a, read=True, timeout=0)
-        start = monotonic()
+        start = time.monotonic()
         try:
             # Start delivering SIGALRM 10 times per second
             signal.setitimer(signal.ITIMER_REAL, 0.1, 0.1)
@@ -197,7 +196,7 @@ def test_eintr_infinite_timeout(wfs, spair):
             # Stop delivering SIGALRM
             signal.setitimer(signal.ITIMER_REAL, 0)
             thread.join()
-        end = monotonic()
+        end = time.monotonic()
         dur = end - start
         assert 0.9 < dur < 3
     finally:
